@@ -7,7 +7,7 @@ AsyncCreator::~AsyncCreator() {
 }
 
 void AsyncCreator::create_next(bool force) {
-    if (force) {
+    if (force && !pending_fns.empty()) {
         pending_fns.pop();
     }
     if ((force && !pending_fns.empty()) || (!force && pending_fns.size() == 1)) {
